@@ -1,19 +1,21 @@
-from __future__ import unicode_literals, absolute_import
+# -*- coding: utf-8 -*-
+from __future__ import absolute_import, unicode_literals
 
 import locale
+import logging
 import os.path
-import six
-
-from jinja2.utils import generate_lorem_ipsum
+from posixpath import join as posix_join
 from sys import platform
 
-from pelican.contents import (Page, Article, Static, URLWrapper,
-                              Author, Category)
+from jinja2.utils import generate_lorem_ipsum
+
+import six
+
+from pelican.contents import Article, Author, Category, Page, Static, Tag
 from pelican.settings import DEFAULT_CONFIG
 from pelican.signals import content_object_init
-from pelican.tests.support import unittest, get_settings
-from pelican.utils import (path_to_url, truncate_html_words, SafeDatetime,
-                           posix_join)
+from pelican.tests.support import LoggedTestCase, get_settings, unittest
+from pelican.utils import SafeDatetime, path_to_url, truncate_html_words
 
 
 # generate one paragraph, enclosed with <p>
@@ -21,7 +23,7 @@ TEST_CONTENT = str(generate_lorem_ipsum(n=1))
 TEST_SUMMARY = generate_lorem_ipsum(n=1, html=False)
 
 
-class TestPage(unittest.TestCase):
+class TestPage(LoggedTestCase):
 
     def setUp(self):
         super(TestPage, self).setUp()
@@ -39,16 +41,26 @@ class TestPage(unittest.TestCase):
             },
             'source_path': '/path/to/file/foo.ext'
         }
+        self._disable_limit_filter()
 
     def tearDown(self):
         locale.setlocale(locale.LC_ALL, self.old_locale)
+        self._enable_limit_filter()
+
+    def _disable_limit_filter(self):
+        from pelican.contents import logger
+        logger.disable_filter()
+
+    def _enable_limit_filter(self):
+        from pelican.contents import logger
+        logger.enable_filter()
 
     def test_use_args(self):
         # Creating a page with arguments passed to the constructor should use
         # them to initialise object's attributes.
         metadata = {'foo': 'bar', 'foobar': 'baz', 'title': 'foobar', }
         page = Page(TEST_CONTENT, metadata=metadata,
-                context={'localsiteurl': ''})
+                    context={'localsiteurl': ''})
         for key, value in metadata.items():
             self.assertTrue(hasattr(page, key))
             self.assertEqual(value, getattr(page, key))
@@ -85,6 +97,18 @@ class TestPage(unittest.TestCase):
         page = Page(**page_kwargs)
         self.assertEqual(page.summary, '')
 
+    def test_summary_get_summary_warning(self):
+        """calling ._get_summary() should issue a warning"""
+        page_kwargs = self._copy_page_kwargs()
+        page = Page(**page_kwargs)
+        self.assertEqual(page.summary, TEST_SUMMARY)
+        self.assertEqual(page._get_summary(), TEST_SUMMARY)
+        self.assertLogCountEqual(
+                count=1,
+                msg="_get_summary\(\) has been deprecated since 3\.6\.4\. "
+                    "Use the summary decorator instead",
+                level=logging.WARNING)
+
     def test_slug(self):
         page_kwargs = self._copy_page_kwargs()
         settings = get_settings()
@@ -138,14 +162,9 @@ class TestPage(unittest.TestCase):
         page = Page(**page_kwargs)
 
         # page.locale_date is a unicode string in both python2 and python3
-        dt_date = dt.strftime(DEFAULT_CONFIG['DEFAULT_DATE_FORMAT']) 
-        # dt_date is a byte string in python2, and a unicode string in python3
-        # Let's make sure it is a unicode string (relies on python 3.3 supporting the u prefix)
-        if type(dt_date) != type(u''):
-            # python2:
-            dt_date = unicode(dt_date, 'utf8')
+        dt_date = dt.strftime(DEFAULT_CONFIG['DEFAULT_DATE_FORMAT'])
 
-        self.assertEqual(page.locale_date, dt_date )
+        self.assertEqual(page.locale_date, dt_date)
         page_kwargs['settings'] = get_settings()
 
         # I doubt this can work on all platforms ...
@@ -297,6 +316,19 @@ class TestPage(unittest.TestCase):
             '?utm_whatever=234&highlight=word#section-2">link</a>'
         )
 
+        # also test for summary in metadata
+        args['metadata']['summary'] = (
+            'A simple summary test, with a '
+            '<a href="|filename|article.rst">link</a>'
+        )
+        args['context']['localsiteurl'] = 'http://notmyidea.org'
+        p = Page(**args)
+        self.assertEqual(
+            p.summary,
+            'A simple summary test, with a '
+            '<a href="http://notmyidea.org/article.html">link</a>'
+        )
+
     def test_intrasite_link_more(self):
         # type does not take unicode in PY2 and bytes in PY3, which in
         # combination with unicode literals leads to following insane line:
@@ -306,10 +338,14 @@ class TestPage(unittest.TestCase):
         args['settings'] = get_settings()
         args['source_path'] = 'content'
         args['context']['filenames'] = {
-            'images/poster.jpg': type(cls_name, (object,), {'url': 'images/poster.jpg'}),
-            'assets/video.mp4': type(cls_name, (object,), {'url': 'assets/video.mp4'}),
-            'images/graph.svg': type(cls_name, (object,), {'url': 'images/graph.svg'}),
-            'reference.rst': type(cls_name, (object,), {'url': 'reference.html'}),
+            'images/poster.jpg': type(
+                cls_name, (object,), {'url': 'images/poster.jpg'}),
+            'assets/video.mp4': type(
+                cls_name, (object,), {'url': 'assets/video.mp4'}),
+            'images/graph.svg': type(
+                cls_name, (object,), {'url': 'images/graph.svg'}),
+            'reference.rst': type(
+                cls_name, (object,), {'url': 'reference.html'}),
         }
 
         # video.poster
@@ -324,20 +360,25 @@ class TestPage(unittest.TestCase):
             content,
             'There is a video with poster '
             '<video controls poster="http://notmyidea.org/images/poster.jpg">'
-            '<source src="http://notmyidea.org/assets/video.mp4" type="video/mp4">'
+            '<source src="http://notmyidea.org/assets/video.mp4"'
+            ' type="video/mp4">'
             '</video>'
         )
 
         # object.data
         args['content'] = (
             'There is a svg object '
-            '<object data="{filename}/images/graph.svg" type="image/svg+xml"></object>'
+            '<object data="{filename}/images/graph.svg"'
+            ' type="image/svg+xml">'
+            '</object>'
         )
         content = Page(**args).get_content('http://notmyidea.org')
         self.assertEqual(
             content,
             'There is a svg object '
-            '<object data="http://notmyidea.org/images/graph.svg" type="image/svg+xml"></object>'
+            '<object data="http://notmyidea.org/images/graph.svg"'
+            ' type="image/svg+xml">'
+            '</object>'
         )
 
         # blockquote.cite
@@ -349,7 +390,9 @@ class TestPage(unittest.TestCase):
         self.assertEqual(
             content,
             'There is a blockquote with cite attribute '
-            '<blockquote cite="http://notmyidea.org/reference.html">blah blah</blockquote>'
+            '<blockquote cite="http://notmyidea.org/reference.html">'
+            'blah blah'
+            '</blockquote>'
         )
 
     def test_intrasite_link_markdown_spaces(self):
@@ -400,23 +443,65 @@ class TestArticle(TestPage):
 
     def test_slugify_category_author(self):
         settings = get_settings()
-        settings['SLUG_SUBSTITUTIONS'] = [ ('C#', 'csharp') ]
+        settings['SLUG_SUBSTITUTIONS'] = [('C#', 'csharp')]
         settings['ARTICLE_URL'] = '{author}/{category}/{slug}/'
         settings['ARTICLE_SAVE_AS'] = '{author}/{category}/{slug}/index.html'
         article_kwargs = self._copy_page_kwargs()
         article_kwargs['metadata']['author'] = Author("O'Brien", settings)
-        article_kwargs['metadata']['category'] = Category('C# & stuff', settings)
+        article_kwargs['metadata']['category'] = Category(
+            'C# & stuff', settings)
         article_kwargs['metadata']['title'] = 'fnord'
         article_kwargs['settings'] = settings
         article = Article(**article_kwargs)
         self.assertEqual(article.url, 'obrien/csharp-stuff/fnord/')
-        self.assertEqual(article.save_as, 'obrien/csharp-stuff/fnord/index.html')
+        self.assertEqual(
+            article.save_as, 'obrien/csharp-stuff/fnord/index.html')
+
+    def test_slugify_with_author_substitutions(self):
+        settings = get_settings()
+        settings['AUTHOR_SUBSTITUTIONS'] = [
+                                    ('Alexander Todorov', 'atodorov', False),
+                                    ('Krasimir Tsonev', 'krasimir', False),
+        ]
+        settings['ARTICLE_URL'] = 'blog/{author}/{slug}/'
+        settings['ARTICLE_SAVE_AS'] = 'blog/{author}/{slug}/index.html'
+        article_kwargs = self._copy_page_kwargs()
+        article_kwargs['metadata']['author'] = Author('Alexander Todorov',
+                                                      settings)
+        article_kwargs['metadata']['title'] = 'fnord'
+        article_kwargs['settings'] = settings
+        article = Article(**article_kwargs)
+        self.assertEqual(article.url, 'blog/atodorov/fnord/')
+        self.assertEqual(article.save_as, 'blog/atodorov/fnord/index.html')
+
+    def test_slugify_category_with_dots(self):
+        settings = get_settings()
+        settings['CATEGORY_SUBSTITUTIONS'] = [('Fedora QA', 'fedora.qa', True)]
+        settings['ARTICLE_URL'] = '{category}/{slug}/'
+        article_kwargs = self._copy_page_kwargs()
+        article_kwargs['metadata']['category'] = Category('Fedora QA',
+                                                          settings)
+        article_kwargs['metadata']['title'] = 'This Week in Fedora QA'
+        article_kwargs['settings'] = settings
+        article = Article(**article_kwargs)
+        self.assertEqual(article.url, 'fedora.qa/this-week-in-fedora-qa/')
+
+    def test_slugify_tags_with_dots(self):
+        settings = get_settings()
+        settings['TAG_SUBSTITUTIONS'] = [('Fedora QA', 'fedora.qa', True)]
+        settings['ARTICLE_URL'] = '{tag}/{slug}/'
+        article_kwargs = self._copy_page_kwargs()
+        article_kwargs['metadata']['tag'] = Tag('Fedora QA', settings)
+        article_kwargs['metadata']['title'] = 'This Week in Fedora QA'
+        article_kwargs['settings'] = settings
+        article = Article(**article_kwargs)
+        self.assertEqual(article.url, 'fedora.qa/this-week-in-fedora-qa/')
 
 
-class TestStatic(unittest.TestCase):
+class TestStatic(LoggedTestCase):
 
     def setUp(self):
-
+        super(TestStatic, self).setUp()
         self.settings = get_settings(
             STATIC_SAVE_AS='{path}',
             STATIC_URL='{path}',
@@ -425,7 +510,8 @@ class TestStatic(unittest.TestCase):
         self.context = self.settings.copy()
 
         self.static = Static(content=None, metadata={}, settings=self.settings,
-            source_path=posix_join('dir', 'foo.jpg'), context=self.context)
+                             source_path=posix_join('dir', 'foo.jpg'),
+                             context=self.context)
 
         self.context['filenames'] = {self.static.source_path: self.static}
 
@@ -435,8 +521,10 @@ class TestStatic(unittest.TestCase):
     def test_attach_to_same_dir(self):
         """attach_to() overrides a static file's save_as and url.
         """
-        page = Page(content="fake page",
-            metadata={'title': 'fakepage'}, settings=self.settings,
+        page = Page(
+            content="fake page",
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'fakepage.md'))
         self.static.attach_to(page)
 
@@ -448,7 +536,7 @@ class TestStatic(unittest.TestCase):
         """attach_to() preserves dirs inside the linking document dir.
         """
         page = Page(content="fake page", metadata={'title': 'fakepage'},
-            settings=self.settings, source_path='fakepage.md')
+                    settings=self.settings, source_path='fakepage.md')
         self.static.attach_to(page)
 
         expected_save_as = os.path.join('outpages', 'dir', 'foo.jpg')
@@ -459,8 +547,8 @@ class TestStatic(unittest.TestCase):
         """attach_to() ignores dirs outside the linking document dir.
         """
         page = Page(content="fake page",
-            metadata={'title': 'fakepage'}, settings=self.settings,
-            source_path=os.path.join('dir', 'otherdir', 'fakepage.md'))
+                    metadata={'title': 'fakepage'}, settings=self.settings,
+                    source_path=os.path.join('dir', 'otherdir', 'fakepage.md'))
         self.static.attach_to(page)
 
         expected_save_as = os.path.join('outpages', 'foo.jpg')
@@ -471,8 +559,8 @@ class TestStatic(unittest.TestCase):
         """attach_to() does nothing when called a second time.
         """
         page = Page(content="fake page",
-            metadata={'title': 'fakepage'}, settings=self.settings,
-            source_path=os.path.join('dir', 'fakepage.md'))
+                    metadata={'title': 'fakepage'}, settings=self.settings,
+                    source_path=os.path.join('dir', 'fakepage.md'))
 
         self.static.attach_to(page)
 
@@ -480,8 +568,10 @@ class TestStatic(unittest.TestCase):
         otherdir_settings.update(dict(
             PAGE_SAVE_AS=os.path.join('otherpages', '{slug}.html'),
             PAGE_URL='otherpages/{slug}.html'))
-        otherdir_page = Page(content="other page",
-            metadata={'title': 'otherpage'}, settings=otherdir_settings,
+        otherdir_page = Page(
+            content="other page",
+            metadata={'title': 'otherpage'},
+            settings=otherdir_settings,
             source_path=os.path.join('dir', 'otherpage.md'))
 
         self.static.attach_to(otherdir_page)
@@ -496,8 +586,10 @@ class TestStatic(unittest.TestCase):
         """
         original_save_as = self.static.save_as
 
-        page = Page(content="fake page",
-            metadata={'title': 'fakepage'}, settings=self.settings,
+        page = Page(
+            content="fake page",
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'fakepage.md'))
         self.static.attach_to(page)
 
@@ -510,8 +602,10 @@ class TestStatic(unittest.TestCase):
         """
         original_url = self.static.url
 
-        page = Page(content="fake page",
-            metadata={'title': 'fakepage'}, settings=self.settings,
+        page = Page(
+            content="fake page",
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'fakepage.md'))
         self.static.attach_to(page)
 
@@ -522,13 +616,15 @@ class TestStatic(unittest.TestCase):
         """attach_to() does not override paths that were overridden elsewhere.
         (For example, by the user with EXTRA_PATH_METADATA)
         """
-        customstatic = Static(content=None,
+        customstatic = Static(
+            content=None,
             metadata=dict(save_as='customfoo.jpg', url='customfoo.jpg'),
             settings=self.settings,
             source_path=os.path.join('dir', 'foo.jpg'),
             context=self.settings.copy())
 
-        page = Page(content="fake page",
+        page = Page(
+            content="fake page",
             metadata={'title': 'fakepage'}, settings=self.settings,
             source_path=os.path.join('dir', 'fakepage.md'))
 
@@ -541,13 +637,16 @@ class TestStatic(unittest.TestCase):
         """{attach} link syntax triggers output path override & url replacement.
         """
         html = '<a href="{attach}../foo.jpg">link</a>'
-        page = Page(content=html,
-            metadata={'title': 'fakepage'}, settings=self.settings,
+        page = Page(
+            content=html,
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
             context=self.context)
         content = page.get_content('')
 
-        self.assertNotEqual(content, html,
+        self.assertNotEqual(
+            content, html,
             "{attach} link syntax did not trigger URL replacement.")
 
         expected_save_as = os.path.join('outpages', 'foo.jpg')
@@ -560,7 +659,8 @@ class TestStatic(unittest.TestCase):
         html = '<a href="{tag}foo">link</a>'
         page = Page(
             content=html,
-            metadata={'title': 'fakepage'}, settings=self.settings,
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
             context=self.context)
         content = page.get_content('')
@@ -571,10 +671,63 @@ class TestStatic(unittest.TestCase):
         "{category} link syntax triggers url replacement."
 
         html = '<a href="{category}foo">link</a>'
-        page = Page(content=html,
-            metadata={'title': 'fakepage'}, settings=self.settings,
+        page = Page(
+            content=html,
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
             source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
             context=self.context)
         content = page.get_content('')
 
         self.assertNotEqual(content, html)
+
+    def test_author_link_syntax(self):
+        "{author} link syntax triggers url replacement."
+
+        html = '<a href="{author}foo">link</a>'
+        page = Page(
+            content=html,
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
+            source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
+            context=self.context)
+        content = page.get_content('')
+
+        self.assertNotEqual(content, html)
+
+    def test_index_link_syntax(self):
+        "{index} link syntax triggers url replacement."
+
+        html = '<a href="{index}">link</a>'
+        page = Page(
+            content=html,
+            metadata={'title': 'fakepage'},
+            settings=self.settings,
+            source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
+            context=self.context)
+        content = page.get_content('')
+
+        self.assertNotEqual(content, html)
+
+        expected_html = ('<a href="' +
+                         '/'.join((self.settings['SITEURL'],
+                                   self.settings['INDEX_SAVE_AS'])) +
+                         '">link</a>')
+        self.assertEqual(content, expected_html)
+
+    def test_unknown_link_syntax(self):
+        "{unknown} link syntax should trigger warning."
+
+        html = '<a href="{unknown}foo">link</a>'
+        page = Page(content=html,
+                    metadata={'title': 'fakepage'}, settings=self.settings,
+                    source_path=os.path.join('dir', 'otherdir', 'fakepage.md'),
+                    context=self.context)
+        content = page.get_content('')
+
+        self.assertEqual(content, html)
+        self.assertLogCountEqual(
+            count=1,
+            msg="Replacement Indicator 'unknown' not recognized, "
+                "skipping replacement",
+            level=logging.WARNING)
