@@ -1,16 +1,19 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals, print_function
+﻿# -*- coding: utf-8 -*-
+from __future__ import print_function, unicode_literals
 
+import locale
 import os
 import re
 
-import locale
 from codecs import open
-from pelican.tools.pelican_import import wp2fields, fields2pelican, decode_wp_content, build_header, build_markdown_header, get_attachments, download_attachments
-from pelican.tests.support import (unittest, temporary_folder, mute,
-                                   skipIfNoExecutable)
 
-from pelican.utils import slugify, path_to_file_url
+from pelican.tests.support import (mute, skipIfNoExecutable, temporary_folder,
+                                   unittest)
+from pelican.tools.pelican_import import (build_header, build_markdown_header,
+                                          decode_wp_content,
+                                          download_attachments, fields2pelican,
+                                          get_attachments, wp2fields)
+from pelican.utils import path_to_file_url, slugify
 
 CUR_DIR = os.path.abspath(os.path.dirname(__file__))
 WORDPRESS_XML_SAMPLE = os.path.join(CUR_DIR, 'content', 'wordpressexport.xml')
@@ -32,7 +35,6 @@ except ImportError:
     LXML = False
 
 
-
 @skipIfNoExecutable(['pandoc', '--version'])
 @unittest.skipUnless(BeautifulSoup, 'Needs BeautifulSoup module')
 class TestWordpressXmlImporter(unittest.TestCase):
@@ -48,17 +50,19 @@ class TestWordpressXmlImporter(unittest.TestCase):
 
     def test_ignore_empty_posts(self):
         self.assertTrue(self.posts)
-        for title, content, fname, date, author, categ, tags, status, kind, format in self.posts:
-            self.assertTrue(title.strip())
+        for (title, content, fname, date, author,
+             categ, tags, status, kind, format) in self.posts:
+                self.assertTrue(title.strip())
 
     def test_recognise_page_kind(self):
         """ Check that we recognise pages in wordpress, as opposed to posts """
         self.assertTrue(self.posts)
         # Collect (title, filename, kind) of non-empty posts recognised as page
         pages_data = []
-        for title, content, fname, date, author, categ, tags, status, kind, format in self.posts:
-            if kind == 'page':
-                pages_data.append((title, fname))
+        for (title, content, fname, date, author,
+             categ, tags, status, kind, format) in self.posts:
+                if kind == 'page':
+                    pages_data.append((title, fname))
         self.assertEqual(2, len(pages_data))
         self.assertEqual(('Page', 'contact'), pages_data[0])
         self.assertEqual(('Empty Page', 'empty'), pages_data[1])
@@ -67,7 +71,8 @@ class TestWordpressXmlImporter(unittest.TestCase):
         silent_f2p = mute(True)(fields2pelican)
         test_post = filter(lambda p: p[0].startswith("Empty Page"), self.posts)
         with temporary_folder() as temp:
-            fname = list(silent_f2p(test_post, 'markdown', temp, dirpage=True))[0]
+            fname = list(silent_f2p(test_post, 'markdown',
+                                    temp, dirpage=True))[0]
             self.assertTrue(fname.endswith('pages%sempty.md' % os.path.sep))
 
     def test_dircat(self):
@@ -75,10 +80,11 @@ class TestWordpressXmlImporter(unittest.TestCase):
         test_posts = []
         for post in self.posts:
             # check post kind
-            if len(post[5]) > 0: # Has a category
+            if len(post[5]) > 0:  # Has a category
                 test_posts.append(post)
         with temporary_folder() as temp:
-            fnames = list(silent_f2p(test_posts, 'markdown', temp, dircat=True))
+            fnames = list(silent_f2p(test_posts, 'markdown',
+                                     temp, dircat=True))
         index = 0
         for post in test_posts:
             name = post[2]
@@ -92,25 +98,33 @@ class TestWordpressXmlImporter(unittest.TestCase):
     def test_unless_custom_post_all_items_should_be_pages_or_posts(self):
         self.assertTrue(self.posts)
         pages_data = []
-        for title, content, fname, date, author, categ, tags, status, kind, format in self.posts:
-            if kind == 'page' or kind == 'article':
-                pass
-            else:
-                pages_data.append((title, fname))
+        for (title, content, fname, date, author, categ,
+             tags, status, kind, format) in self.posts:
+                if kind == 'page' or kind == 'article':
+                    pass
+                else:
+                    pages_data.append((title, fname))
         self.assertEqual(0, len(pages_data))
 
     def test_recognise_custom_post_type(self):
         self.assertTrue(self.custposts)
         cust_data = []
-        for title, content, fname, date, author, categ, tags, status, kind, format in self.custposts:
-            if kind == 'article' or kind == 'page':
-                pass
-            else:
-                cust_data.append((title, kind))
+        for (title, content, fname, date, author, categ,
+             tags, status, kind, format) in self.custposts:
+                if kind == 'article' or kind == 'page':
+                    pass
+                else:
+                    cust_data.append((title, kind))
         self.assertEqual(3, len(cust_data))
-        self.assertEqual(('A custom post in category 4', 'custom1'), cust_data[0])
-        self.assertEqual(('A custom post in category 5', 'custom1'), cust_data[1])
-        self.assertEqual(('A 2nd custom post type also in category 5', 'custom2'), cust_data[2])
+        self.assertEqual(
+            ('A custom post in category 4', 'custom1'),
+            cust_data[0])
+        self.assertEqual(
+            ('A custom post in category 5', 'custom1'),
+            cust_data[1])
+        self.assertEqual(
+            ('A 2nd custom post type also in category 5', 'custom2'),
+            cust_data[2])
 
     def test_custom_posts_put_in_own_dir(self):
         silent_f2p = mute(True)(fields2pelican)
@@ -122,7 +136,8 @@ class TestWordpressXmlImporter(unittest.TestCase):
             else:
                 test_posts.append(post)
         with temporary_folder() as temp:
-            fnames = list(silent_f2p(test_posts, 'markdown', temp, wp_custpost = True))
+            fnames = list(silent_f2p(test_posts, 'markdown',
+                                     temp, wp_custpost=True))
         index = 0
         for post in test_posts:
             name = post[2]
@@ -144,7 +159,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
                 test_posts.append(post)
         with temporary_folder() as temp:
             fnames = list(silent_f2p(test_posts, 'markdown', temp,
-                wp_custpost=True, dircat=True))
+                                     wp_custpost=True, dircat=True))
         index = 0
         for post in test_posts:
             name = post[2]
@@ -157,7 +172,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
             index += 1
 
     def test_wp_custpost_true_dirpage_false(self):
-        #pages should only be put in their own directory when dirpage = True
+        # pages should only be put in their own directory when dirpage = True
         silent_f2p = mute(True)(fields2pelican)
         test_posts = []
         for post in self.custposts:
@@ -166,7 +181,7 @@ class TestWordpressXmlImporter(unittest.TestCase):
                 test_posts.append(post)
         with temporary_folder() as temp:
             fnames = list(silent_f2p(test_posts, 'markdown', temp,
-                wp_custpost=True, dirpage=False))
+                                     wp_custpost=True, dirpage=False))
         index = 0
         for post in test_posts:
             name = post[2]
@@ -175,7 +190,6 @@ class TestWordpressXmlImporter(unittest.TestCase):
             out_name = fnames[index]
             self.assertFalse(out_name.endswith(filename))
 
-
     def test_can_toggle_raw_html_code_parsing(self):
         def r(f):
             with open(f, encoding='utf-8') as infile:
@@ -184,10 +198,12 @@ class TestWordpressXmlImporter(unittest.TestCase):
 
         with temporary_folder() as temp:
 
-            rst_files = (r(f) for f in silent_f2p(self.posts, 'markdown', temp))
+            rst_files = (r(f) for f
+                         in silent_f2p(self.posts, 'markdown', temp))
             self.assertTrue(any('<iframe' in rst for rst in rst_files))
-            rst_files = (r(f) for f in silent_f2p(self.posts, 'markdown', temp,
-                         strip_raw=True))
+            rst_files = (r(f) for f
+                         in silent_f2p(self.posts, 'markdown',
+                                       temp, strip_raw=True))
             self.assertFalse(any('<iframe' in rst for rst in rst_files))
             # no effect in rst
             rst_files = (r(f) for f in silent_f2p(self.posts, 'rst', temp))
@@ -197,13 +213,14 @@ class TestWordpressXmlImporter(unittest.TestCase):
             self.assertFalse(any('<iframe' in rst for rst in rst_files))
 
     def test_decode_html_entities_in_titles(self):
-        test_posts = [post for post in self.posts if post[2] == 'html-entity-test']
+        test_posts = [post for post
+                      in self.posts if post[2] == 'html-entity-test']
         self.assertEqual(len(test_posts), 1)
 
         post = test_posts[0]
         title = post[0]
-        self.assertTrue(title, "A normal post with some <html> entities in the"
-                               " title. You can't miss them.")
+        self.assertTrue(title, "A normal post with some <html> entities in "
+                               "the title. You can't miss them.")
         self.assertNotIn('&', title)
 
     def test_decode_wp_content_returns_empty(self):
@@ -216,14 +233,18 @@ class TestWordpressXmlImporter(unittest.TestCase):
             encoded_content = encoded_file.read()
             with open(WORDPRESS_DECODED_CONTENT_SAMPLE, 'r') as decoded_file:
                 decoded_content = decoded_file.read()
-                self.assertEqual(decode_wp_content(encoded_content, br=False), decoded_content)
+                self.assertEqual(
+                    decode_wp_content(encoded_content, br=False),
+                    decoded_content)
 
     def test_preserve_verbatim_formatting(self):
         def r(f):
             with open(f, encoding='utf-8') as infile:
                 return infile.read()
         silent_f2p = mute(True)(fields2pelican)
-        test_post = filter(lambda p: p[0].startswith("Code in List"), self.posts)
+        test_post = filter(
+            lambda p: p[0].startswith("Code in List"),
+            self.posts)
         with temporary_folder() as temp:
             md = [r(f) for f in silent_f2p(test_post, 'markdown', temp)][0]
             self.assertTrue(re.search(r'\s+a = \[1, 2, 3\]', md))
@@ -231,14 +252,17 @@ class TestWordpressXmlImporter(unittest.TestCase):
 
             for_line = re.search(r'\s+for i in zip\(a, b\):', md).group(0)
             print_line = re.search(r'\s+print i', md).group(0)
-            self.assertTrue(for_line.rindex('for') < print_line.rindex('print'))
+            self.assertTrue(
+                for_line.rindex('for') < print_line.rindex('print'))
 
     def test_code_in_list(self):
         def r(f):
             with open(f, encoding='utf-8') as infile:
                 return infile.read()
         silent_f2p = mute(True)(fields2pelican)
-        test_post = filter(lambda p: p[0].startswith("Code in List"), self.posts)
+        test_post = filter(
+            lambda p: p[0].startswith("Code in List"),
+            self.posts)
         with temporary_folder() as temp:
             md = [r(f) for f in silent_f2p(test_post, 'markdown', temp)][0]
             sample_line = re.search(r'-   This is a code sample', md).group(0)
@@ -285,26 +309,29 @@ class TestBuildHeader(unittest.TestCase):
         self.assertEqual(build_header(*header_data), expected_docutils)
         self.assertEqual(build_markdown_header(*header_data), expected_md)
 
-
     def test_build_header_with_east_asian_characters(self):
         header = build_header('これは広い幅の文字だけで構成されたタイトルです',
-                None, None, None, None, None)
+                              None, None, None, None, None)
 
         self.assertEqual(header,
-                'これは広い幅の文字だけで構成されたタイトルです\n' +
-                '##############################################\n\n')
+                         ('これは広い幅の文字だけで構成されたタイトルです\n'
+                          '##############################################'
+                          '\n\n'))
 
     def test_galleries_added_to_header(self):
-        header = build_header('test', None, None, None, None,
-                None, attachments=['output/test1', 'output/test2'])
-        self.assertEqual(header, 'test\n####\n' + ':attachments: output/test1, '
-                + 'output/test2\n\n')
+        header = build_header('test', None, None, None, None, None,
+                              attachments=['output/test1', 'output/test2'])
+        self.assertEqual(header, ('test\n####\n'
+                                  ':attachments: output/test1, '
+                                  'output/test2\n\n'))
 
     def test_galleries_added_to_markdown_header(self):
         header = build_markdown_header('test', None, None, None, None, None,
-            attachments=['output/test1', 'output/test2'])
-        self.assertEqual(header, 'Title: test\n' + 'Attachments: output/test1, '
-                + 'output/test2\n\n')
+                                       attachments=['output/test1',
+                                                    'output/test2'])
+        self.assertEqual(
+            header,
+            'Title: test\nAttachments: output/test1, output/test2\n\n')
 
 
 @unittest.skipUnless(BeautifulSoup, 'Needs BeautifulSoup module')
@@ -326,14 +353,24 @@ class TestWordpressXMLAttachements(unittest.TestCase):
         self.assertTrue(self.attachments)
         for post in self.attachments.keys():
             if post is None:
-                self.assertTrue(self.attachments[post][0] == 'https://upload.wikimedia.org/wikipedia/commons/thumb/2/2c/Pelican_lakes_entrance02.jpg/240px-Pelican_lakes_entrance02.jpg')
+                expected = ('https://upload.wikimedia.org/wikipedia/commons/'
+                            'thumb/2/2c/Pelican_lakes_entrance02.jpg/'
+                            '240px-Pelican_lakes_entrance02.jpg')
+                self.assertEqual(self.attachments[post][0], expected)
             elif post == 'with-excerpt':
-                self.assertTrue(self.attachments[post][0] == 'http://thisurlisinvalid.notarealdomain/not_an_image.jpg')
-                self.assertTrue(self.attachments[post][1] == 'http://en.wikipedia.org/wiki/File:Pelikan_Walvis_Bay.jpg')
+                expected_invalid = ('http://thisurlisinvalid.notarealdomain/'
+                                    'not_an_image.jpg')
+                expected_pelikan = ('http://en.wikipedia.org/wiki/'
+                                    'File:Pelikan_Walvis_Bay.jpg')
+                self.assertEqual(self.attachments[post][0], expected_invalid)
+                self.assertEqual(self.attachments[post][1], expected_pelikan)
             elif post == 'with-tags':
-                self.assertTrue(self.attachments[post][0] == 'http://thisurlisinvalid.notarealdomain')
+                expected_invalid = ('http://thisurlisinvalid.notarealdomain')
+                self.assertEqual(self.attachments[post][0], expected_invalid)
             else:
-                self.fail('all attachments should match to a filename or None, {}'.format(post))
+                self.fail('all attachments should match to a '
+                          'filename or None, {}'
+                          .format(post))
 
     def test_download_attachments(self):
         real_file = os.path.join(CUR_DIR, 'content/article.rst')
@@ -344,4 +381,6 @@ class TestWordpressXMLAttachements(unittest.TestCase):
             locations = list(silent_da(temp, [good_url, bad_url]))
             self.assertEqual(1, len(locations))
             directory = locations[0]
-            self.assertTrue(directory.endswith(os.path.join('content', 'article.rst')), directory)
+            self.assertTrue(
+                directory.endswith(os.path.join('content', 'article.rst')),
+                directory)
